@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* e-vcard.c
  *
- * Copyright (C) 2003 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -288,7 +288,7 @@ read_attribute_value (EVCardAttribute *attr, char **p, gboolean quoted_printable
 			lp = g_utf8_next_char(lp);
 		}
 		else if ((*lp == ';') ||
-			 (*lp == ',' && !strcmp (attr->name, "CATEGORIES"))) {
+			 (*lp == ',' && !g_ascii_strcasecmp (attr->name, "CATEGORIES"))) {
 			e_vcard_attribute_add_value (attr, str->str);
 			g_string_assign (str, "");
 			lp = g_utf8_next_char(lp);
@@ -619,18 +619,22 @@ parse (EVCard *evc, const char *str)
 	if (!attr || attr->group || g_ascii_strcasecmp (attr->name, "begin")) {
 		g_warning ("vcard began without a BEGIN:VCARD\n");
 	}
-	if (attr && !g_ascii_strcasecmp (attr->name, "begin"))
+	if (attr && !g_ascii_strcasecmp (attr->name, "begin")) {
 		e_vcard_attribute_free (attr);
-	else if (attr)
+		attr = NULL;
+	} else if (attr)
 		e_vcard_add_attribute (evc, attr);
 
 	while (*p) {
 		EVCardAttribute *next_attr = read_attribute (&p);
 
 		if (next_attr) {
+			attr = next_attr;
+
 			if (g_ascii_strcasecmp (next_attr->name, "end"))
 				e_vcard_add_attribute (evc, next_attr);
-			attr = next_attr;
+			else
+				break;
 		}
 	}
 
@@ -846,11 +850,24 @@ e_vcard_to_string_vcard_30 (EVCard *evc)
 						}
 						pval = g_utf8_next_char (pval);
 					}
-					if (quotes)
+
+					if (quotes) {
+						int i;
+
 						g_string_append_c (attr_str, '"');
-					g_string_append (attr_str, value);
-					if (quotes)
+
+						for (i = 0; value [i]; i++) {
+							/* skip quotes in quoted string; it is not allowed */
+							if (value [i] == '\"')
+								continue;
+
+							g_string_append_c (attr_str, value [i]);
+						}
+
 						g_string_append_c (attr_str, '"');
+					} else
+						g_string_append (attr_str, value);
+
 					if (v->next)
 						g_string_append_c (attr_str, ',');
 				}
@@ -870,7 +887,7 @@ e_vcard_to_string_vcard_30 (EVCard *evc)
 				/* XXX toshok - i hate you, rfc 2426.
 				   why doesn't CATEGORIES use a ; like
 				   a normal list attribute? */
-				if (!strcmp (attr->name, "CATEGORIES"))
+				if (!g_ascii_strcasecmp (attr->name, "CATEGORIES"))
 					g_string_append_c (attr_str, ',');
 				else
 					g_string_append_c (attr_str, ';');
@@ -889,13 +906,17 @@ e_vcard_to_string_vcard_30 (EVCard *evc)
 			gchar *pos1 = attr_str->str;
 			gchar *pos2 = pos1;
 			pos2 = g_utf8_offset_to_pointer (pos2, 75);
+			len -= 75;
 
-			do {
+			while (1) {
 				g_string_append_len (fold_str, pos1, pos2 - pos1);
 				g_string_append (fold_str, CRLF " ");
 				pos1 = pos2;
+				if (len <= 74)
+					break;
 				pos2 = g_utf8_offset_to_pointer (pos2, 74);
-			} while (pos2 < attr_str->str + attr_str->len);
+				len -= 74;
+			}
 			g_string_append (fold_str, pos1);
 			g_string_free (attr_str, TRUE);
 			attr_str = fold_str;
@@ -1699,7 +1720,7 @@ e_vcard_get_attribute (EVCard     *evc,
                 EVCardAttribute *attr;
 
                 attr = (EVCardAttribute *) l->data;
-                if (strcmp (attr->name, name) == 0)
+                if (g_ascii_strcasecmp (attr->name, name) == 0)
                         return attr;
         }
 
