@@ -1,8 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* Evolution calendar - generic backend class
  *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Federico Mena-Quintero <federico@ximian.com>
  *          Rodrigo Moya <rodrigo@ximian.com>
@@ -18,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CAL_BACKEND_H
@@ -72,7 +71,7 @@ struct _ECalBackendClass {
 	void (* get_alarm_email_address) (ECalBackend *backend, EDataCal *cal);
 	void (* get_ldap_attribute) (ECalBackend *backend, EDataCal *cal);
 	void (* get_static_capabilities) (ECalBackend *backend, EDataCal *cal);
-	
+
 	void (* open) (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists, const char *username, const char *password);
 	void (* remove) (ECalBackend *backend, EDataCal *cal);
 
@@ -87,11 +86,11 @@ struct _ECalBackendClass {
 	void (* send_objects) (ECalBackend *backend, EDataCal *cal, const char *calobj);
 
 	void (* get_default_object) (ECalBackend *backend, EDataCal *cal);
-	void (* get_object) (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);	
+	void (* get_object) (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);
 	void (* get_object_list) (ECalBackend *backend, EDataCal *cal, const char *sexp);
 
-	void (* get_attachment_list) (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);	
-	
+	void (* get_attachment_list) (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid);
+
 	/* Timezone related virtual methods */
 	void (* get_timezone) (ECalBackend *backend, EDataCal *cal, const char *tzid);
 	void (* add_timezone) (ECalBackend *backend, EDataCal *cal, const char *object);
@@ -123,6 +122,7 @@ void e_cal_backend_remove_client (ECalBackend *backend, EDataCal *cal);
 
 void e_cal_backend_add_query (ECalBackend *backend, EDataCalView *query);
 EList *e_cal_backend_get_queries (ECalBackend *backend);
+void e_cal_backend_remove_query (ECalBackend *backend, EDataCalView *query);
 
 void e_cal_backend_is_read_only (ECalBackend *backend, EDataCal *cal);
 void e_cal_backend_get_cal_address (ECalBackend *backend, EDataCal *cal);
@@ -174,12 +174,13 @@ void e_cal_backend_notify_object_modified (ECalBackend *backend, const char *old
 void e_cal_backend_notify_object_removed  (ECalBackend *backend, const ECalComponentId *id, const char *old_object, const char *object);
 
 void e_cal_backend_notify_mode      (ECalBackend *backend,
-				     GNOME_Evolution_Calendar_CalListener_SetModeStatus status, 
+				     GNOME_Evolution_Calendar_CalListener_SetModeStatus status,
 				     GNOME_Evolution_Calendar_CalMode mode);
 void e_cal_backend_notify_auth_required (ECalBackend *backend);
 void e_cal_backend_notify_error     (ECalBackend *backend, const char *message);
 
 void e_cal_backend_notify_view_done (ECalBackend *backend, GNOME_Evolution_Calendar_CallStatus status);
+void e_cal_backend_notify_view_progress_start (ECalBackend *backend);
 void e_cal_backend_notify_view_progress (ECalBackend *backend, const char *message, int percent);
 void e_cal_backend_notify_readonly (ECalBackend *backend, gboolean read_only);
 void e_cal_backend_notify_cal_address (ECalBackend *backend, char *address);
