@@ -3,8 +3,8 @@
   FILE: icaltime.c
   CREATOR: eric 02 June 2000
   
-  $Id: icaltime.c,v 1.37.2.1 2005/09/05 05:04:32 pchen Exp $
-  $Locker:  $
+  $Id: icaltime.c 633 2008-02-18 07:26:45Z pchen $
+  $Locker$
     
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
@@ -45,19 +45,29 @@
 #include "icalvalue.h"
 
 #ifdef WIN32
-#include <Windows.h>
+#include <windows.h>
 
 #define snprintf      _snprintf
 #define strcasecmp    stricmp
 #endif
 
+#ifdef WIN32
+/* Undef the similar macro from pthread.h, it doesn't check if
+ * gmtime() returns NULL.
+ */
+#undef gmtime_r
+
+/* The gmtime() in Microsoft's C library is MT-safe */
+#define gmtime_r(tp,tmp) (gmtime(tp)?(*(tmp)=*gmtime(tp),(tmp)):0)
+#endif
+
 #ifdef HAVE_PTHREAD
  #include <pthread.h>    
     static pthread_mutex_t tzid_mutex = PTHREAD_MUTEX_INITIALIZER;
 #endif
 
-static char * access_saved_tz ();
 static void release_saved_tz ();
+static char * access_saved_tz ();
 
 /*
  *  Function to convert a struct tm time specification
@@ -195,9 +205,13 @@ icaltime_from_timet_with_zone(const time_t tm, const int is_date,
 
     /* Convert the time_t to a struct tm in UTC time. We can trust gmtime
        for this. */
-    t = *(gmtime(&tm));
+#ifdef HAVE_PTHREAD
+    gmtime_r (&tm, &t);
+#else
+    t = *(gmtime (&tm));
+#endif
      
-     tt.year   = t.tm_year + 1900;
+    tt.year   = t.tm_year + 1900;
     tt.month  = t.tm_mon + 1;
     tt.day    = t.tm_mday;
     tt.hour   = t.tm_hour;
@@ -292,7 +306,8 @@ time_t icaltime_as_timet(const struct icaltimetype tt)
 static char* saved_tz = NULL;
 
 /* If you use set_tz(), you must call unset_tz() some time later to restore the
-   original TZ. Pass unset_tz() the string that set_tz() returns. */
+   original TZ. Pass unset_tz() the string that set_tz() returns. Call both the functions
+   locking the tzid mutex as in icaltime_as_timet_with_zone */
 char* set_tz(const char* tzid)
 {
     char *old_tz, *old_tz_copy = NULL, *new_tz;
@@ -327,14 +342,11 @@ char* set_tz(const char* tzid)
 
     /* Free any previous TZ environment string we have used in a synchronized manner. */
 
-    if (access_saved_tz ()) 
-      free (saved_tz);
+    free (saved_tz);
 
     /* Save a pointer to the TZ string we just set, so we can free it later. */
     saved_tz = new_tz;
 
-    release_saved_tz ();
-
     return old_tz_copy; /* This will be zero if the TZ env var was not set */
 }
 
@@ -358,15 +370,11 @@ void unset_tz(char *tzstr)
     } 
 
     /* Free any previous TZ environment string we have used in a synchronized manner */
-
-    if (access_saved_tz ()) 
-	free (saved_tz);
+    free (saved_tz);
 
     /* Save a pointer to the TZ string we just set, so we can free it later.
        (This can possibly be NULL if there was no TZ to restore.) */
     saved_tz = tzstr;
-
-    release_saved_tz ();	
 }
 
 /**	Return the time as seconds past the UNIX epoch, using the
@@ -411,12 +419,28 @@ time_t icaltime_as_timet_with_zone(const struct icaltimetype tt,
     stm.tm_mon = local_tt.month-1;
     stm.tm_year = local_tt.year-1900;
     stm.tm_isdst = -1;
+/* The functions putenv and mktime are not thread safe, inserting a lock
+to prevent any crashes */
 
+#ifdef HAVE_PTHREAD
+    pthread_mutex_lock (&tzid_mutex);
+#endif
+    
     /* Set TZ to UTC and use mktime to convert to a time_t. */
     old_tz = set_tz ("UTC");
+#ifdef WIN32
+    tzset ();
+#endif
+
     t = mktime (&stm);
     unset_tz (old_tz);
+#ifdef WIN32
+    tzset ();
+#endif
 
+#ifdef HAVE_PTHREAD
+    pthread_mutex_unlock (&tzid_mutex);
+#endif
     return t;
 }
 
@@ -424,7 +448,7 @@ time_t icaltime_as_timet_with_zone(const struct icaltimetype tt,
  * Return a string represention of the time, in RFC2445 format. The
  * string is owned by libical
  */
-const char* icaltime_as_ical_string(const struct icaltimetype tt)
+char* icaltime_as_ical_string(const struct icaltimetype tt)
 {
     size_t size = 17;
     char* buf = icalmemory_new_buffer(size);
@@ -442,10 +466,7 @@ const char* icaltime_as_ical_string(const struct icaltimetype tt)
 		 tt.hour,tt.minute,tt.second);
     }
     
-    icalmemory_add_tmp_buffer(buf);
-
     return buf;
-
 }
 
 /**
@@ -1166,32 +1187,3 @@ int icaltime_span_contains(icaltime_span *s,
   return 0;
 }
 
-/* @brief gives access the static variable saved_tz synchronously  
- * @return		The pointer to the saved_tz
- *
- */
-
-static char * access_saved_tz ()
-{
- 
-	#ifdef HAVE_PTHREAD
-	    pthread_mutex_lock (&tzid_mutex);
-	#endif
-	return saved_tz;
-
-}
-
-
-/* @brief releases the access to the static variable saved_tz synchronously  
- *
- */
-
-static void release_saved_tz ()
-{
- 
-	#ifdef HAVE_PTHREAD
-	    pthread_mutex_unlock (&tzid_mutex);
-	#endif
-	return;
-
-}
