@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@novell.com>
  *
- *  Copyright 2005 Novell, Inc. (www.novell.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -60,7 +60,7 @@ struct _CamelOfflineFolderClass {
 
 CamelType camel_offline_folder_get_type (void);
 
-void camel_offline_folder_downsync (CamelOfflineFolder *folder, const char *expression, CamelException *ex);
+void camel_offline_folder_downsync (CamelOfflineFolder *offline, const char *expression, CamelException *ex);
 
 G_END_DECLS
 
