@@ -6,7 +6,7 @@
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *  Dan Winship <danw@ximian.com>
  *
- * Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of version 2 of the GNU Lesser General Public 
@@ -42,7 +42,7 @@
 #include "camel-store.h"
 #include "camel-vtrash-folder.h"
 
-#define d(x)
+#define d(x) 
 #define w(x)
 
 static CamelServiceClass *parent_class = NULL;
@@ -153,11 +153,17 @@ camel_store_finalize (CamelObject *object)
 {
 	CamelStore *store = CAMEL_STORE (object);
 
+	d(printf ("\ncamel_store_finalize called \n"));
 	if (store->folders)
 		camel_object_bag_destroy(store->folders);
 	
 	g_static_rec_mutex_free (&store->priv->folder_lock);
-	
+
+	if (store->cdb) {
+		camel_db_close (store->cdb);
+		store->cdb = NULL;
+	}
+
 	g_free (store->priv);
 }
 
@@ -200,11 +206,58 @@ construct (CamelService *service, CamelSession *session,
 	   CamelException *ex)
 {
 	CamelStore *store = CAMEL_STORE(service);
+	char *store_db_path, *store_path = NULL;
 
 	parent_class->construct(service, session, provider, url, ex);
 	if (camel_exception_is_set (ex))
 		return;
 
+	store_db_path = g_build_filename (service->url->path, CAMEL_DB_FILE, NULL);
+
+	if (!service->url->path || strlen (store_db_path) < 2) {
+		store_path = camel_session_get_storage_path (session, service, ex);
+
+		g_free (store_db_path);
+		store_db_path = g_build_filename (store_path, CAMEL_DB_FILE, NULL);
+	}
+
+	if (!g_file_test (service->url->path ? service->url->path : store_path, G_FILE_TEST_EXISTS)) {
+		/* Cache might be blown. Recreate. */
+		g_mkdir_with_parents (service->url->path ? service->url->path : store_path, S_IRWXU);
+	}
+
+	g_free (store_path);
+
+	store->cdb = camel_db_open (store_db_path, ex);
+	printf("store_db_path %s\n", store_db_path);
+	if (camel_exception_is_set (ex)) {
+		char *store_path;
+		
+		g_print ("Failure for store_db_path : [%s]\n", store_db_path);
+		g_free (store_db_path);		
+
+		store_path =  camel_session_get_storage_path (session, service, ex);
+		store_db_path = g_build_filename (store_path, CAMEL_DB_FILE, NULL);
+		g_free (store_path);
+		camel_exception_clear(ex);
+		store->cdb = camel_db_open (store_db_path, ex);
+		if (camel_exception_is_set (ex)) {
+			g_print("Retry with %s failed\n", store_db_path);
+			g_free(store_db_path);
+			camel_exception_clear(ex);
+			return;
+		}
+	}
+	g_free (store_db_path);
+
+	if (camel_db_create_folders_table (store->cdb, ex))
+		printf ("something went wrong terribly\n");
+	else
+		printf ("folders table succesfully created \n");
+
+	if (camel_exception_is_set (ex))
+		return;
+
 	if (camel_url_get_param(url, "filter"))
 		store->flags |= CAMEL_STORE_FILTER_INBOX;
 }
@@ -212,7 +265,7 @@ construct (CamelService *service, CamelSession *session,
 static CamelFolder *
 get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
 {
-	w(g_warning ("CamelStore::get_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::get_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
@@ -230,7 +283,7 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
  *
  * Get a specific folder object from the store by name.
  *
- * Returns the folder corresponding to the path @folder_name.
+ * Returns: the folder corresponding to the path @folder_name.
  **/
 CamelFolder *
 camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
@@ -249,7 +302,7 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 		folder = camel_object_bag_reserve(store->folders, folder_name);
 		if (folder && (flags & CAMEL_STORE_FOLDER_EXCL)) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Cannot create folder `%s': folder exists"),
+					      _("Cannot create folder '%s': folder exists"),
 					      folder_name);
                         camel_object_bag_abort (store->folders, folder_name);
 			camel_object_unref (folder);
@@ -309,7 +362,7 @@ static CamelFolderInfo *
 create_folder (CamelStore *store, const char *parent_name,
 	       const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::create_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::create_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
@@ -328,7 +381,7 @@ create_folder (CamelStore *store, const char *parent_name,
  * Creates a new folder as a child of an existing folder.
  * @parent_name can be %NULL to create a new top-level folder.
  *
- * Returns info about the created folder, which the caller must
+ * Returns: info about the created folder, which the caller must
  * free with #camel_store_free_folder_info
  **/
 CamelFolderInfo *
@@ -384,7 +437,7 @@ cs_delete_cached_folder(CamelStore *store, const char *folder_name)
 static void
 delete_folder (CamelStore *store, const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::delete_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::delete_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -417,8 +470,10 @@ camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelExce
 
 	if (!camel_exception_is_set(&local))
 		cs_delete_cached_folder(store, folder_name);
-	else
+	else {
 		camel_exception_xfer(ex, &local);
+		printf("excep: %s\n", camel_exception_get_description (ex));
+	}
 	
 	CAMEL_STORE_UNLOCK(store, folder_lock);
 }
@@ -426,7 +481,7 @@ camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelExce
 static void
 rename_folder (CamelStore *store, const char *old_name, const char *new_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::rename_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::rename_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -549,7 +604,7 @@ get_inbox (CamelStore *store, CamelException *ex)
  * @store: a #CamelStore object
  * @ex: a #CamelException
  *
- * Returns the folder in the store into which new mail is delivered,
+ * Returns: the folder in the store into which new mail is delivered,
  * or %NULL if no such folder exists.
  **/
 CamelFolder *
@@ -565,7 +620,7 @@ camel_store_get_inbox (CamelStore *store, CamelException *ex)
 }
 
 static CamelFolder *
-get_special(CamelStore *store, enum _camel_vtrash_folder_t type)
+get_special(CamelStore *store, camel_vtrash_folder_t type)
 {
 	CamelFolder *folder;
 	GPtrArray *folders;
@@ -600,7 +655,7 @@ get_junk(CamelStore *store, CamelException *ex)
  * @store: a #CamelStore object
  * @ex: a #CamelException
  *
- * Returns the folder in the store into which trash is delivered, or
+ * Returns: the folder in the store into which trash is delivered, or
  * %NULL if no such folder exists.
  **/
 CamelFolder *
@@ -617,7 +672,7 @@ camel_store_get_trash (CamelStore *store, CamelException *ex)
  * @store: a #CamelStore object
  * @ex: a #CamelException
  *
- * Returns the folder in the store into which junk is delivered, or
+ * Returns: the folder in the store into which junk is delivered, or
  * %NULL if no such folder exists.
  **/
 CamelFolder *
@@ -674,7 +729,7 @@ camel_store_sync(CamelStore *store, int expunge, CamelException *ex)
 static CamelFolderInfo *
 get_folder_info (CamelStore *store, const char *top, guint32 flags, CamelException *ex)
 {
-	w(g_warning ("CamelStore::get_folder_info not implemented for `%s'",
+	w(g_warning ("CamelStore::get_folder_info not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	return NULL;
@@ -781,7 +836,7 @@ dump_fi(CamelFolderInfo *fi, int depth)
  * supplied or not.  The only guaranteed way to get updated folder
  * counts is to both open the folder and invoke refresh_info() it.
  *
- * Returns a #CamelFolderInfo tree, which must be freed with
+ * Returns: a #CamelFolderInfo tree, which must be freed with
  * #camel_store_free_folder_info
  **/
 CamelFolderInfo *
@@ -816,7 +871,7 @@ camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, C
 static void
 free_folder_info (CamelStore *store, CamelFolderInfo *fi)
 {
-	w(g_warning ("CamelStore::free_folder_info not implemented for `%s'",
+	w(g_warning ("CamelStore::free_folder_info not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -920,7 +975,7 @@ folder_info_cmp (const void *ap, const void *bp)
  * NOTE: This is deprected, do not use this.
  * FIXME: remove this/move it to imap, which is the only user of it now.
  *
- * Returns the top level of the tree of linked folder info.
+ * Returns: the top level of the tree of linked folder info.
  **/
 CamelFolderInfo *
 camel_folder_info_build (GPtrArray *folders, const char *namespace,
@@ -1057,7 +1112,7 @@ folder_info_clone_rec(CamelFolderInfo *fi, CamelFolderInfo *parent)
  *
  * Clones @fi recursively.
  *
- * Returns the cloned #CamelFolderInfo tree.
+ * Returns: the cloned #CamelFolderInfo tree.
  **/
 CamelFolderInfo *
 camel_folder_info_clone(CamelFolderInfo *fi)
@@ -1075,7 +1130,7 @@ camel_folder_info_clone(CamelFolderInfo *fi)
  *
  * Get whether or not @store supports subscriptions to folders.
  *
- * Returns %TRUE if folder subscriptions are supported or %FALSE otherwise
+ * Returns: %TRUE if folder subscriptions are supported or %FALSE otherwise
  **/
 gboolean
 camel_store_supports_subscriptions (CamelStore *store)
@@ -1086,7 +1141,7 @@ camel_store_supports_subscriptions (CamelStore *store)
 static gboolean
 folder_subscribed(CamelStore *store, const char *folder_name)
 {
-	w(g_warning ("CamelStore::folder_subscribed not implemented for `%s'",
+	w(g_warning ("CamelStore::folder_subscribed not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	return FALSE;
@@ -1099,7 +1154,7 @@ folder_subscribed(CamelStore *store, const char *folder_name)
  *
  * Find out if a folder has been subscribed to.
  *
- * Returns %TRUE if the folder has been subscribed to or %FALSE otherwise
+ * Returns: %TRUE if the folder has been subscribed to or %FALSE otherwise
  **/
 gboolean
 camel_store_folder_subscribed(CamelStore *store, const char *folder_name)
@@ -1121,7 +1176,7 @@ camel_store_folder_subscribed(CamelStore *store, const char *folder_name)
 static void
 subscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::subscribe_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::subscribe_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -1149,7 +1204,7 @@ camel_store_subscribe_folder(CamelStore *store, const char *folder_name, CamelEx
 static void
 unsubscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::unsubscribe_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::unsubscribe_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -1213,7 +1268,7 @@ camel_store_noop (CamelStore *store, CamelException *ex)
  *
  * Compares 2 folder uris to check that they are equal.
  *
- * Returns %TRUE if they are equal or %FALSE otherwise
+ * Returns: %TRUE if they are equal or %FALSE otherwise
  **/
 int
 camel_store_folder_uri_equal (CamelStore *store, const char *uri0, const char *uri1)
@@ -1269,15 +1324,16 @@ can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex
 
 /**
  * camel_store_can_refresh_folder
+ * @store: a #CamelStore
+ * @info: a #CamelFolderInfo
+ * @ex: a #CamelException
+ *
  * Returns if this folder (param info) should be checked for new mail or not.
  * It should not look into sub infos (info->child) or next infos, it should
  * return value only for the actual folder info.
  * Default behavior is that all Inbox folders are intended to be refreshed.
  *
- * @param store Store, to which belong folder.
- * @param info Info of folder of our interest.
- * @param ex [out] Will set this exception in case of any error.
- * @return Whether folder should be checked for new mails or not.
+ * Returns: whether folder should be checked for new mails
  **/
 gboolean
 camel_store_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex)
