@@ -40,8 +40,6 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <libedataserver/e-msgport.h>
-
 #include <e-gw-connection.h>
 #include <e-gw-item.h>
 
@@ -674,6 +672,7 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 
 				gw_info->info.flags &= ~CAMEL_MESSAGE_FOLDER_FLAGGED;
 				gw_info->info.dirty = 1;
+				camel_folder_summary_touch (folder->summary);
 				gw_info->server_flags = gw_info->info.flags;
 				uid = camel_message_info_uid (info);
 				if (diff.bits & CAMEL_MESSAGE_DELETED) {
@@ -1571,12 +1570,6 @@ gw_update_summary ( CamelFolder *folder, GList *list,CamelException *ex)
 				str = g_string_append (str, " ");
 			}
 
-                        if (org->display_name && org->display_name[0] == '\0') { 
-				
-                                str = g_string_append (str, org->email);
-				str = g_string_append (str, " ");
-			}
-
 			if (org->email && org->email[0]) { 
 				g_string_append (str, "<");
 				str = g_string_append (str, org->email);
