@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-pop3-store.c : class for a pop3 store */
 
-/*
+/* 
  * Authors:
  *   Dan Winship <danw@ximian.com>
  *   Michael Zucchi <notzed@ximian.com>
  *
- * Copyright (C) 2000-2002 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -67,7 +67,7 @@ static gboolean pop3_connect (CamelService *service, CamelException *ex);
 static gboolean pop3_disconnect (CamelService *service, gboolean clean, CamelException *ex);
 static GList *query_auth_types (CamelService *service, CamelException *ex);
 
-static CamelFolder *get_folder (CamelStore *store, const char *folder_name,
+static CamelFolder *get_folder (CamelStore *store, const char *folder_name, 
 				guint32 flags, CamelException *ex);
 
 static CamelFolder *get_trash  (CamelStore *store, CamelException *ex);
@@ -83,7 +83,7 @@ camel_pop3_store_class_init (CamelPOP3StoreClass *camel_pop3_store_class)
 		CAMEL_STORE_CLASS (camel_pop3_store_class);
 
 	parent_class = CAMEL_STORE_CLASS (camel_type_get_global_classfuncs (camel_store_get_type ()));
-
+	
 	/* virtual method overload */
 	camel_service_class->query_auth_types = query_auth_types;
 	camel_service_class->connect = pop3_connect;
@@ -158,7 +158,7 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 	int clean_quit = TRUE;
 	int ret;
 	const gchar *delete_days;
-
+	
 	if (ssl_mode != MODE_CLEAR) {
 #ifdef HAVE_SSL
 		if (ssl_mode == MODE_TLS) {
@@ -210,12 +210,12 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 		camel_object_unref (tcp_stream);
 		return FALSE;
 	}
-
+	
 	if (ssl_mode != MODE_TLS) {
 		camel_object_unref (tcp_stream);
 		return TRUE;
 	}
-
+	
 #ifdef HAVE_SSL
 	/* as soon as we send a STLS command, all hope is lost of a clean QUIT if problems arise */
 	clean_quit = FALSE;
@@ -273,11 +273,11 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 			;
 		camel_pop3_engine_command_free (store->engine, pc);
 	}
-
+	
 	camel_object_unref (CAMEL_OBJECT (store->engine));
 	camel_object_unref (CAMEL_OBJECT (tcp_stream));
 	store->engine = NULL;
-
+	
 	return FALSE;
 }
 
@@ -315,13 +315,13 @@ connect_to_server_wrapper (CamelService *service, CamelException *ex)
 		serv = "pop3";
 		port = POP3S_PORT;
 	}
-
+	
 	if (service->url->port) {
 		serv = g_alloca (16);
 		sprintf (serv, "%d", service->url->port);
 		port = NULL;
 	}
-
+	
 	memset (&hints, 0, sizeof (hints));
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_family = PF_UNSPEC;
@@ -330,14 +330,14 @@ connect_to_server_wrapper (CamelService *service, CamelException *ex)
 		camel_exception_clear (ex);
 		ai = camel_getaddrinfo(service->url->host, port, &hints, ex);
 	}
-
+	
 	if (ai == NULL)
 		return FALSE;
-
+	
 	ret = connect_to_server (service, ai, mode, ex);
-
+	
 	camel_freeaddrinfo (ai);
-
+	
 	return ret;
 }
 
@@ -416,7 +416,7 @@ try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
 			break;
 		if (strncmp((char *) line, "-ERR", 4) == 0) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
-					      _("SASL `%s' Login failed for POP server %s: %s"),
+					      _("SASL '%s' Login failed for POP server %s: %s"),
 					      mech, CAMEL_SERVICE (store)->url->host, line);
 			goto done;
 		}
@@ -441,7 +441,7 @@ try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
 	}
 	camel_object_unref((CamelObject *)sasl);
 	return 0;
-
+	
  ioerror:
 	if (errno == EINTR) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
@@ -531,17 +531,17 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 				return try_sasl(store, service->url->authmech, ex) == -1;
 			l = l->next;
 		}
-
+		
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
 				      _("Unable to connect to POP server %s: "
 					"No support for requested authentication mechanism."),
 				      CAMEL_SERVICE (store)->url->host);
 		return FALSE;
 	}
-
+	
 	while ((status = camel_pop3_engine_iterate(store->engine, pcp)) > 0)
 		;
-
+	
 	if (status == -1) {
 		if (errno == EINTR) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
@@ -581,9 +581,9 @@ pop3_connect (CamelService *service, CamelException *ex)
 	CamelSession *session;
 	char *errbuf = NULL;
 	int status;
-
+	
 	session = camel_service_get_session (service);
-
+	
 	if (store->cache == NULL) {
 		char *root;
 
@@ -598,15 +598,15 @@ pop3_connect (CamelService *service, CamelException *ex)
 			}
 		}
 	}
-
+	
 	if (!connect_to_server_wrapper (service, ex))
 		return FALSE;
-
+	
 	while (1) {
 		status = pop3_try_authenticate (service, reprompt, errbuf, ex);
 		g_free (errbuf);
 		errbuf = NULL;
-
+		
 		/* we only re-prompt if we failed to authenticate, any other error and we just abort */
 		if (status == 0 && camel_exception_get_id (ex) == CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE) {
 			errbuf = g_markup_printf_escaped ("%s\n\n", camel_exception_get_description (ex));
@@ -617,18 +617,18 @@ pop3_connect (CamelService *service, CamelException *ex)
 		} else
 			break;
 	}
-
+	
 	g_free (errbuf);
-
+	
 	if (status == -1 || camel_exception_is_set(ex)) {
 		camel_service_disconnect(service, TRUE, ex);
 		return FALSE;
 	}
-
+	
 	/* Now that we are in the TRANSACTION state, try regetting the capabilities */
 	store->engine->state = CAMEL_POP3_ENGINE_TRANSACTION;
 	camel_pop3_engine_reget_capabilities (store->engine);
-
+	
 	return TRUE;
 }
 
@@ -636,22 +636,22 @@ static gboolean
 pop3_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
-
+	
 	if (clean) {
 		CamelPOP3Command *pc;
-
+		
 		pc = camel_pop3_engine_command_new(store->engine, 0, NULL, NULL, "QUIT\r\n");
 		while (camel_pop3_engine_iterate(store->engine, NULL) > 0)
 			;
 		camel_pop3_engine_command_free(store->engine, pc);
 	}
-
+	
 	if (!CAMEL_SERVICE_CLASS (parent_class)->disconnect (service, clean, ex))
 		return FALSE;
-
+	
 	camel_object_unref((CamelObject *)store->engine);
 	store->engine = NULL;
-
+	
 	return TRUE;
 }
 
@@ -660,7 +660,7 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
 {
 	if (g_ascii_strcasecmp (folder_name, "inbox") != 0) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
-				      _("No such folder `%s'."), folder_name);
+				      _("No such folder '%s'."), folder_name);
 		return NULL;
 	}
 	return camel_pop3_folder_new (store, ex);
